#!/usr/bin/gnuplot

# Miroslav Broz (miroslav.broz@email.cz), Jul 26th 2002

set colors classic
#set term x11

set tit ""
set xl "diameter {/Helvetica-Oblique D} / km"
set yl "number of asteroids {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.25,0

set xr [10.e-9:1000]
miny=0.8
maxy=2e26
set yr [miny:maxy]
set logscale xy
set xtics 10
set mxtics 10
set ytics 10
set mytics 10
set key samplen 1.0 spacing 1.5
set xtics format "10^{%T}"
set ytics format "10^{%T}"

set arrow from 1,graph 0 rto 0,graph 1 nohead lt 0
set arrow from 0.001,graph 0 rto 0,graph 1 nohead lt 0
set arrow from 100.e-9,graph 0 rto 0,graph 1 nohead lt 0

f_family1(x)  = (10**4.05095018e+00) * x**(-1.50954101e+00)  # Vesta
f_family8(x)  = (10**3.04947554e+00) * x**(-2.91181685e+00)  # Karin; observed
f_family9(x)  = (10**3.04947554e+00) * x**(-2.8)
f_family10(x) = (10**3.04947554e+00) * x**(-3.0)
#f_family9(x)  = (10**3.04947554e+00) * x**(-3.0)  # Karin; to fit IRAS 2.1deg band, t = 0
#f_family10(x) = (10**3.04947554e+00) * x**(-3.1)  # Karin; to fit IRAS 2.1deg band, t = 6 My
f_family0(x)  = (1e13) * (x/0.001)**(-2.7)  # MB

tmp=0.5; set label sprintf("  %.1f  ", -2.91181685e+00) at tmp,f_family8(tmp) font "Helvetica,14" right

set arrow from 1.0e-3,30e10 to 1.0e-3,60e10 heads lc 'black' front size graph 0.01,90 fixed

p \
  "<echo 100.e-9  9.7e24" w p pt 1 ps 3 lw 8 lc '#0066ff' t "zodiacal cloud",\
  "<echo 100.e-9  1.3e24" w p pt 1 ps 3 lw 8 lc '#cc00ff' t "IRAS 2.1{/Symbol\260} band",\
  "<echo  30.e-9  5.4e24" w p pt 2 ps 3 lw 1 lc 'gray'    t "N(>30 mu)",\
  "vypocty10_iras.dat" u ($1/1.e3):2 w lp lc '#cc00ff' t "w. SFD of dust",\
  "vypocty11_iras.dat" u ($1/1.e3):2 w lp lc '#cc00ff' t "w. SFD of dust",\
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../../boulder/33_MB_Karin/*[0-9]*/tmp/0006.out | ./hc.awk" u 1:2 t "evolved MB"    w l lw 2 lc '#0066ff',\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../../boulder/33_MB_Karin/*[0-9]*/tmp/0000.out | ./hc.awk" u 1:2 t "initial Karin" w l lw 2 lc 'gray',\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../../boulder/33_MB_Karin/*[0-9]*/tmp/0006.out | ./hc.awk" u 1:2 t "evolved Karin" w l lw 2 lc '#cc00ff',\
  "../../boulder/dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) not w p pt 7 lc '#ffffff',\
  "../../boulder/dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) t "{/=14 Bottke etal. (2015)}" w p pt 7 lc '#000066',\
  "<awk '($1>-1) && ($1<0.2)' ../../boulder/dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) not w p pt 7 lc '#ffffff',\
  "<awk '($1>-1) && ($1<0.2)' ../../boulder/dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) not w p pt 7 lc '#000066',\
  f_family8(x)  not lc '#ffaaff' dt 2,\
  f_family0(x) not lc 'gray'    dt 2,\
  "../../main_belt_families_2021Jun/832_Karin/size_distribution/family.dat_hc"         w l lc '#000066' lw 3 t "Karin (L/H)"

pa -1

set term postscript eps enh color solid "Helvetica" 18
set out "Karin_DUSTSFD.eps"
set size 0.625*1.5,0.9*1.5
rep

system("eps2png Karin_DUSTSFD.eps")

q

  f_family9(x)  not lc '#ffaaff' dt 2,\
  f_family10(x) not lc '#ffaaff' dt 2,\

