#!/usr/bin/awk -f

# hc_hd.awk
# Cumulative histogram -> differential histogram.
# Miroslav Broz (miroslav.broz@email.cz), Feb 15th 2012

BEGIN{
  extra = 0;
#  print "# D [km] & D+dD [km] & dN";
  print "# D [km] & dN";
}
!/^#/ && (NF>0){
# save cumulative histogram
  i++;
  D[i] = log10($1);
  N_gt_D[i] = log10($2);
}
END{
  n = i;
  eps = 1.e-3;

#  for (i=1; i<=n; i++) { print D[i],N_gt_D[i]; }; exit;  # dbg

# change sort order
  for (i=1; i<=n; i++) {
    D_reverse[i] = D[n-i+1]; 
    N_gt_D_reverse[i] = N_gt_D[n-i+1]; 
  }

#  for (i=1; i<=n; i++) { print D_reverse[i],N_gt_D_reverse[i]; }; exit;  # dbg

#  n = n+1;
#  D_reverse[n] = 10000.;
#  N_gt_D_reverse[n] = 0;

# choose binning and calculate differential histogram
  D1 = -7.;	# km; LOG-SCALE!
  D2 = +3.;
  dD =  0.1;

  prn();

# choose binning and calculate differential histogram
#  D1 =  0.;	# km
#  D2 = 20.;
#  dD =  1.;

#  prn();

# second histogram for large sizes
#  D1 =  20.;	# km
#  D2 = 120.;
#  dD =  10.;

#  prn();
}

func log10(x) {
  return log(x)/log(10.0);
}

func prn() {
  d = D1;
  while (d <= D2-dD+eps) {
    N_gt_D1 = linterp(D_reverse,N_gt_D_reverse,n,d,extra);
    N_gt_D2 = linterp(D_reverse,N_gt_D_reverse,n,d+dD,extra);
#    dN = N_gt_D1 - N_gt_D2;
#    dN_int = int(dN+0.5);

    dN = log10((10.0**N_gt_D1 - 10.0**N_gt_D2));

#    print d, d+dD, dN_int;
#    print d+0.5*dD, dN;
    print 10.0**(d+0.5*dD), 10.0**dN;
    d = d + dD;
  }
}


func linterp(x,y,n,x0,extra, i,y0) {
  if (x0 < x[1]) {
    extra = 1;
    i = 2;
    y0 = y[1];
  } else if (x0 > x[n]) {
    extra = 1;
    i = n
    y0 = y[n];
  } else {
    extra = 0;
    i = 2
    while (x[i] < x0) {
      i++;
    }

    y0 = y[i-1] + (y[i]-y[i-1]) * (x0-x[i-1])/(x[i]-x[i-1]);

  }

#  print x0,"i = ",i,x[i-1],x[i],y[i-1],y[i],y0;	# dbg

  if (extra == 1) {
    print "# Warning: Extrapolation for x0 = ", x0;
  }

  return y0;
}



