#!/usr/bin/gnuplot

set colors classic
set encoding utf8

set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [10.e-9:2000]
y1=0.2
y2=5.e26
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.2 spacing 1.75 font "Helvetica,18"

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#cc00ff' lw 2 pt 1		# evolved Karin
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#666699' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.8

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0

tmp=1.0e-6; set arrow from tmp,1.5e20 to tmp,8.4e17*1.5 size graph 0.02,30 front empty lw 3 lc '#ccaaaa'
tmp=1.0e-4; set arrow from tmp,4.4e14 to tmp,3.2e12*1.5 size graph 0.02,30 front empty lw 3 lc '#ccaaaa'
tmp=1.0e-2; set arrow from tmp,8.1e8  to tmp,9.8e6 *1.5 size graph 0.02,30 front empty lw 3 lc '#ccaaaa'

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family1(x) = (10**3.04947554e+00) * x**(-2.91181685e+00)  # Karin
f_family2(x) = (1.5e3) * x**(-1.4)  # after 100 My

tmp=0.15; set label sprintf("   %.1f   ", -2.91181685e+00) at tmp,1.0*f_family1(tmp) font "Helvetica,14" left
tmp=0.30; set label sprintf("   %.1f   ", -1.4           ) at tmp,0.4*f_family2(tmp) font "Helvetica,14" right

set arrow from 1.0e-3,30e10 to 1.0e-3,60e10 heads lc 'black' lw 3 front size graph 0.02,90 fixed

set label "observed asteroids"             at 1.0e0 ,graph 1.030 center font "Helvetica,14"
set label "{/Helvetica-Bold H chondrites}" at 1.0e-3,graph 1.030 center font "Helvetica,14"
set label "observed dust band"             at 1.0e-7,graph 1.030 center font "Helvetica,14"

set arrow from 2.0e-6,graph 1.030 to 1.0e-4,graph 1.030 lc 'black' lw 1 front size graph 0.01,30 fixed
set arrow from 5.0e-2,graph 1.030 to 1.0e-2,graph 1.030 lc 'black' lw 1 front size graph 0.01,30 fixed

tmp=20.
set label "0 My == initial"  at 5e-7,1.0e9/tmp**0 left  font "Helvetica-Bold,18" tc '#ccaaaa'
set label "5.8 My == today"  at 5e-7,1.0e9/tmp**1 left  font "Helvetica-Bold,18" tc '#cc00ff'
set label "100 My == future" at 5e-7,1.0e9/tmp**2 left  font "Helvetica-Bold,18" tc '#ffaaff'

p \
  "<./hc_sfd.awk ../../72_1_MB_Karin_-3.0_DAHLGREN/src/sfd3.dat_EDITED" u 1:2 w l lw 2 dt 5 lc '#00ccaaaa' t "initial Karin",\
  "<./hc_sfd.awk ../../72_1_MB_Karin_-2.9_DAHLGREN/src/sfd3.dat_EDITED" u 1:2 w l lw 2 dt 5 lc '#aaccaaaa' not,\
  "<./hc_sfd.awk ../../72_1_MB_Karin_-3.1_DAHLGREN/src/sfd3.dat_EDITED" u 1:2 w l lw 2 dt 5 lc '#aaccaaaa' not,\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../../../../marsset_stypes/boulder/23_MB_Vesta/001/tmp/1100.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffcc00' t "evolved Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../../72_0_MB_none/*[0-9]*/tmp/0050.000.out | ./hc.awk"                u 1:2 w l lw 2 lc '#cc0066ff' t "evolved MB",\
  "<awk '(FNR==1){ print \"\"; } ($2==3)' ../../72_1_MB_Karin_-3.0_DAHLGREN/*[0-9]*/tmp/0005.800.out | ./hc.awk" u 1:2 w l lw 2 lc '#cccc00ff' t "evolved Karin",\
  "<awk '(FNR==1){ print \"\"; } ($2==3)' ../../72_1_MB_Karin_-2.9_DAHLGREN/*[0-9]*/tmp/0005.800.out | ./hc.awk" u 1:2 w l lw 2 lc '#eecc00ff' not,\
  "<awk '(FNR==1){ print \"\"; } ($2==3)' ../../72_1_MB_Karin_-3.1_DAHLGREN/*[0-9]*/tmp/0005.800.out | ./hc.awk" u 1:2 w l lw 2 lc '#cccc00ff' not,\
  "errorbars.dat" u 1:2 w filledcurves lc '#ccaaaaaa' t "uncertainty",\
  "<awk '(FNR==1){ print \"\"; } ($2==3)' ../../72_1_MB_Karin_100MY/*[0-9]*/tmp/0100.000.out | ./hc.awk"         u 1:2 w l lw 2 lc '#aaffaaff'   not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p pt 7 ps 0.7 lc '#eeeeee' not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p pt 7 ps 0.5 lc '#bbbbff' t "observed MB",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p pt 7 ps 0.7 lc '#eeeeee' not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p pt 7 ps 0.5 lc '#bbbbff' not,\
  "../src/832_Karin_family.dat_hc" u 1:2 w l lw 3 lc '#bbbbff' t "observed Karin",\
  "<echo  30.e-9 3.6e25 1.8e25" u 1:2:3 w err pt 1 ps 0 lw 5 lc '#0066ff' t "zodiacal cloud",\
  "<echo  30.e-9 5.4e24 2.7e24" u 1:2:3 w err pt 1 ps 0 lw 5 lc '#cc00ff' t "IRAS 2.1{/Symbol\260} band",\

pa -1

#set term postscript eps enh color solid "Helvetica" 18 size 12cm,12cm
set term pdfcairo font "Helvetica,18" size 16cm,16cm
set out "sfd_0005.800_tmp.pdf"
rep

system("eps2png sfd_0005.800_tmp.pdf")

q


  f_family1(x) not lc 'gray' dt 2,\
  f_family2(x) not lc 'gray' dt 2,\


  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l lw 3 dt 4 lc '#ccaaaa' t "initial MB",\

  "<echo 100.e-9 9.7e24 4.85e24" w err pt 1 ps 0 lw 5 lc '#0066ff' t "zodiacal cloud",\
  "<echo 100.e-9 1.3e24 0.65e24" w err pt 1 ps 0 lw 5 lc '#cc00ff' t "IRAS 2.1{/Symbol\260} band",\

  "vypocty10_iras.dat" u ($1/1.e3):2 w lp lc '#cc00ff' t "w. SFD of dust",\
  "vypocty11_iras.dat" u ($1/1.e3):2 w lp lc '#cc00ff' t "w. SFD of dust"

  "4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\

  "8_Flora_family.dat_hc" u 1:2 w l lc '#ff6600' lw 3 t "observed Flora",\
#tmp=1.0e-6; set arrow from tmp,3.4e20 to tmp,7.0e19 size graph 0.01,30 front filled lw 3 lc '#ccaaaa'
#tmp=1.0e-4; set arrow from tmp,5.2e14 to tmp,2.1e14 size graph 0.005,30 front filled lw 3 lc '#ccaaaa'

  f_family2(x) not lc 'gray'    dt 2

