#!/usr/bin/gnuplot

km = 1.e3  # m
mu = 1.e-6  # m

# Nesvorny (2006), Icarus, 181, 107-144, Tab. 5 on p. 19
D = 11.*km
d = 100.*mu
rho = 2000.  # kg m^-3

M = 4./3.*pi*(D/2.)**3*rho
m = 4./3.*pi*(d/2.)**3*rho

N = (D/d)**3.

print "# Karin family:"
print "D = ", D/km, " km"
print "d = ", d/mu, " mu"
print "M = ", M, " kg"
print "m = ", m, " kg"
print "N = ", N

d = 30*mu
N = (D/d)**3.

print "\n# smaller particles:"
print "d = ", d/mu, " mu"
print "N = ", N
print "cf. N(>30 mu) = 5.4e24"

n=4
array d[n]
array N[n]
array m[n]

d[1] = 10*mu
d[2] = 20*mu
d[3] = 50*mu
d[4] = 100*mu

alpha = +2.2  # Nesvorny etal. (2006b), Tab. 5, (Gi) column, differential, not cumulative!

# alpha = 2.2 .. differential
# gamma = alpha-1 = 1.2 .. cumulative
# gamma = (alpha-1)/3 = 0.4 .. cumulative in mass

N[1] = 1.0
do for [i = 1:n] {
  N[i] = N[1]*(d[i]/d[1])**(-alpha)
}
s = 0.0
do for [i = 1:n] {
  s = s + N[i]*d[i]**3;
}
f = D**3/s
S = 0.0
M = 0.0
array s[10]
do for [i = 1:n] {
  N[i] = f*N[i]
  m[i] = 4./3.*pi*(d[i]/2.)**3*rho * N[i]
  s[i] = pi*(d[i]/2.)**2 * N[i]
  M = M + m[i]
  S = S + s[i]
}

print "\n# SFD of particles:"
do for [i = 1:n] {
  print sprintf("d = %3.0f mu .. N = %.6e .. m = %.6f 10^15 kg .. S = %.6f 10^9 km^2", d[i]/mu, N[i], m[i]/1e15, s[i]/km**2/1.e9)
}
print "S = ", S/km**2/1.e9, " 10^9 km^2"
print "M = ", M, " kg"

print "\ncf. N(>30 mu) = 5.4e24"
print "cf. S = 6.9e9 km^2"
print "cf. M = 1.4e15 kg"

array N_gt_d[n]
N_gt_d[n] = N[n]
do for [i = n-1:1:-1] {
  N_gt_d[i] = N_gt_d[i+1]+N[i]
}

print ""
do for [i = 1:n] {
  print sprintf("d = %3.0f mu .. N(>d) = %.6e", d[i]/mu, N_gt_d[i])
}

# Nesvorny (2006), Icarus, 181, 107-144, abstract; it's R = 23 km, not D!
D = 46.*km
d = 100*mu
N = (D/d)**3.
S = N * pi*(d/2.)**2

print "\n# zodiacal cloud (mostly, JFC!):"
print "D = ", D/km, " km"
print "d = ", d/mu, " mu"
print "N = ", N
print "S = ", S/km**2/1.e9, " 10^9 km^2"

# Nesvorny (2010), ApJ, 713, 816-836, 
S = 0.1*S
N = S/(pi*(d/2.)**2)
D = d * N**(1./3.)

print "\n# main-belt dust:"
print "D = ", D/km, " km"
print "d = ", d/mu, " mu"
print "N = ", N
print "S = ", S/km**2/1.e9, " 10^9 km^2"

d = 30*mu
N = (D/d)**3.
S = N * pi*(d/2.)**2

print "\n# smaller particles:"
print "d = ", d/mu, " mu"
print "N = ", N

S = 0.1*S
N = S/(pi*(d/2.)**2)
D = d * N**(1./3.)

print "N = ", N

# 100mu ... mass-distribution peak
# 30mu ... cross section


